==> quadtree_0.1.10.tar.gz: quadtree/R/generics.R <==
#' @include classes.R

setGeneric("as_data_frame", function(x, ...) standardGeneric("as_data_frame"))
setGeneric("as_raster", function(x, ...) standardGeneric("as_raster"))
setGeneric("as_vector", function(x, ...) standardGeneric("as_vector"))
setGeneric("copy", function(x, ...) standardGeneric("copy"))
# setGeneric("extent", function(x, ...) standardGeneric("extent"))
# setGeneric("extract", function(x, y, ...) standardGeneric("extract"))
setGeneric("find_lcp", function(x, ...) standardGeneric("find_lcp"))
setGeneric("find_lcps", function(x, ...) standardGeneric("find_lcps"))
setGeneric("get_neighbors", function(x, y, ...) standardGeneric("get_neighbors"))
setGeneric("lcp_finder", function(x, ...) standardGeneric("lcp_finder"))
setGeneric("lines", function(x, ...) standardGeneric("lines"))
setGeneric("n_cells", function(x, ...) standardGeneric("n_cells"))
setGeneric("plot", function(x, y, ...) standardGeneric("plot"))
setGeneric("points", function(x, ...) standardGeneric("points"))
setGeneric("projection", function(x) standardGeneric("projection"))
setGeneric("projection<-", function(x, value) standardGeneric("projection<-"))
setGeneric("quadtree", function(x, ...) standardGeneric("quadtree"))
setGeneric("read_quadtree", function(x, ...) standardGeneric("read_quadtree"))
setGeneric("set_values", function(x, y, z, ...) standardGeneric("set_values"))
setGeneric("summarize_lcps", function(x, ...) standardGeneric("summarize_lcps"))
setGeneric("summary", function(object, ...) standardGeneric("summary"))
setGeneric("transform_values", function(x, y, ...) standardGeneric("transform_values"))
setGeneric("write_quadtree", function(x, y, ...) standardGeneric("write_quadtree"))
setGeneric("write_quadtree_ptr", function(x, y, ...) standardGeneric("write_quadtree_ptr"))

==> quadtree_0.1.14.tar.gz: quadtree/R/generics.R <==
#' @include classes.R

setGeneric("as_data_frame", function(x, ...) standardGeneric("as_data_frame"))
setGeneric("as_raster", function(x, ...) standardGeneric("as_raster"))
setGeneric("as_vector", function(x, ...) standardGeneric("as_vector"))
setGeneric("copy", function(x, ...) standardGeneric("copy"))
setGeneric("extent", function(x, ...) standardGeneric("extent"))
# setGeneric("extract", function(x, y, ...) standardGeneric("extract"))
setGeneric("find_lcp", function(x, ...) standardGeneric("find_lcp"))
setGeneric("find_lcps", function(x, ...) standardGeneric("find_lcps"))
setGeneric("get_neighbors", function(x, y, ...) standardGeneric("get_neighbors"))
setGeneric("lcp_finder", function(x, ...) standardGeneric("lcp_finder"))
setGeneric("lines", function(x, ...) standardGeneric("lines"))
setGeneric("n_cells", function(x, ...) standardGeneric("n_cells"))
setGeneric("plot", function(x, y, ...) standardGeneric("plot"))
setGeneric("points", function(x, ...) standardGeneric("points"))
setGeneric("projection", function(x) standardGeneric("projection"))
setGeneric("projection<-", function(x, value) standardGeneric("projection<-"))
setGeneric("quadtree", function(x, ...) standardGeneric("quadtree"))
setGeneric("read_quadtree", function(x, ...) standardGeneric("read_quadtree"))
setGeneric("set_values", function(x, y, z, ...) standardGeneric("set_values"))
setGeneric("summarize_lcps", function(x, ...) standardGeneric("summarize_lcps"))
setGeneric("summary", function(object, ...) standardGeneric("summary"))
setGeneric("transform_values", function(x, y, ...) standardGeneric("transform_values"))
setGeneric("write_quadtree", function(x, y, ...) standardGeneric("write_quadtree"))
setGeneric("write_quadtree_ptr", function(x, y, ...) standardGeneric("write_quadtree_ptr"))
